import React from 'react'
import { useDrag, useDrop } from 'react-dnd'
import { Popover } from 'antd'
import { EditOutlined, CloseOutlined } from '@ant-design/icons'

import MkIcon from '@/components/mk-icon'
import './index.scss'

const Card = ({ id, card, moveCard, findCard, editCard, closeCard, changeGroup }) => {
  const originalIndex = findCard(id).index
  const [{ isDragging }, drag] = useDrag({
    item: { type: 'search', id, originalIndex },
    collect: monitor => ({
      isDragging: monitor.isDragging(),
    }),
  })
  const [, drop] = useDrop({
    accept: 'search',
    canDrop: () => true,
    drop: (item) => {
      const { id: draggedId } = item

      if (draggedId && draggedId !== id) {
        const { index: overIndex } = findCard(id)
        moveCard(draggedId, overIndex)
      }
    }
  })
  const opacity = isDragging ? 0 : 1

  const edit = () => {
    editCard(id)
  }

  const close = () => {
    closeCard(id)
  }

  const change = () => {
    changeGroup(id)
  }

  return (
    <Popover overlayClassName="mk-popover-control-wrap" mouseLeaveDelay={0.2} mouseEnterDelay={0.2} content={
      <div className="mk-popover-control">
        <EditOutlined className="edit" onClick={edit} />
        <CloseOutlined className="close" onClick={close} />
      </div>
    } trigger="hover">
      <div className="page-card" onDoubleClick={change} style={{ opacity: opacity}}>
        <div ref={node => drag(drop(node))}>
          {card.wrap.icon ? <div className="icon">
            <MkIcon type={card.wrap.icon} />
          </div> : null}
          <div className="name">
            {card.wrap.name}
          </div>
        </div>
      </div>
    </Popover>
  )
}
export default Card
